@@ -395,12 +395,22 @@ def write_union(fo, datum, schema):
             raise ValueError(msg)
     else:
         pytype = type(datum)
+        best_match_index = -1
+        most_fields = -1
         for index, candidate in enumerate(schema):
             if validate(datum, candidate):
-                break
-        else:
+                if extract_record_type(candidate) == 'record':
+                    fields = len(candidate['fields'])
+                    if fields > most_fields:
+                        best_match_index = index
+                        most_fields = fields
+                else:
+                    best_match_index = index
+                    break
+        if best_match_index < 0:
             msg = '%r (type %s) do not match %s' % (datum, pytype, schema)
             raise ValueError(msg)
+        index = best_match_index
 
     # write data
     write_long(fo, index)
@@ -478,6 +488,9 @@ def write_data(fo, datum, schema):
     return fn(fo, datum, schema)
 
 
+dump = write_data
+
+
 def write_header(fo, metadata, sync_marker):
     header = {
         'magic': MAGIC,
