@@ -5,10 +5,18 @@
 Some of this code is "lifted" from CherryPy.
 '''
 import sys
-import json
 from sys import stdout
 from struct import unpack
 
+_HAS_UJSON = False
+
+try:
+    import ujson as json
+
+    _HAS_UJSON = True
+except ImportError:
+    import json
+
 _encoding = 'UTF-8'
 
 if sys.version_info >= (3, 0):
@@ -23,11 +31,17 @@ if sys.version_info >= (3, 0):
     def py3_json_dump(obj, indent):
         json.dump(obj, stdout, indent=indent)
 
+    def py3_iterkeys(obj):
+        return obj.keys()
+
+    def py3_itervalues(obj):
+        return obj.values()
+
     def py3_iteritems(obj):
         return obj.items()
 
     def py3_is_str(obj):
-        return isinstance(obj, (bytes, str,))
+        return isinstance(obj, str)
 
     def py3_mk_bits(bits):
         return bytes([bits & 0xff])
@@ -51,7 +65,16 @@ else:  # Python 2x
     _outenc = getattr(stdout, 'encoding', None) or _encoding
 
     def py2_json_dump(obj, indent):
-        json.dump(obj, stdout, indent=indent, encoding=_outenc)
+        if _HAS_UJSON:
+            json.dump(obj, stdout, indent=indent)
+        else:
+            json.dump(obj, stdout, indent=indent, encoding=_outenc)
+
+    def py2_iterkeys(obj):
+        return obj.iterkeys()
+
+    def py2_itervalues(obj):
+        return obj.itervalues()
 
     def py2_iteritems(obj):
         return obj.iteritems()
@@ -74,6 +97,8 @@ if sys.version_info >= (3, 0):
     utob = py3_utob
     json_dump = py3_json_dump
     long = int
+    iterkeys = py3_iterkeys
+    itervalues = py3_itervalues
     iteritems = py3_iteritems
     is_str = py3_is_str
     mk_bits = py3_mk_bits
@@ -83,6 +108,8 @@ else:
     btou = py2_btou
     utob = py2_utob
     json_dump = py2_json_dump
+    iterkeys = py2_iterkeys
+    itervalues = py2_itervalues
     iteritems = py2_iteritems
     long = long
     is_str = py2_is_str
